@@ -1,30 +1,19 @@
-package Devel::Gladiator;
-
-use 5.008;
 use strict;
 use warnings;
+package Devel::Gladiator;
+# git description: v0.04-13-g9daf2ec
+$Devel::Gladiator::VERSION = '0.05';
+# ABSTRACT: Walk Perl's arena
+# KEYWORDS: development debugging memory allocation usage leaks cycles arena
 
-require Exporter;
+use base 'Exporter';
 
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration       use Devel::Gladiator ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw(
-	walk_arena arena_ref_counts arena_table
+    walk_arena arena_ref_counts arena_table
 ) ] );
 
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our $VERSION = '0.04';
-our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;  # see L<perlmodstyle>
-
 sub arena_ref_counts {
     my $all = Devel::Gladiator::walk_arena();
     my %ct;
@@ -48,20 +37,30 @@ sub arena_table {
     return $ret;
 }
 
-require XSLoader;
-XSLoader::load('Devel::Gladiator', $XS_VERSION);
-
-# Preloaded methods go here.
+use XSLoader;
+XSLoader::load(
+    __PACKAGE__,
+    exists $Devel::Gladiator::{VERSION}
+        ? ${ $Devel::Gladiator::{VERSION} }
+        : (),
+);
 
 1;
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::Gladiator - Walk Perl's arena
 
+=head1 VERSION
+
+version 0.05
+
 =head1 SYNOPSIS
 
   use Devel::Gladiator qw(walk_arena arena_ref_counts arena_table);
@@ -76,43 +75,83 @@ Devel::Gladiator - Walk Perl's arena
 
 =head1 DESCRIPTION
 
-L<Devel::Gladiator> iterate's Perl's internal memory structures and can be used
+L<Devel::Gladiator> iterates Perl's internal memory structures and can be used
 to enumerate all the currently live SVs.
 
 This can be used to hunt leaks and to profile memory usage.
 
 =head1 EXPORTS
 
-=over 4
-
-=item walk_arena
+=head2 walk_arena
 
 Returns an array reference containing all the live SVs. Note that this will
 include a reference back to itself, so you should manually clear this array
 (via C<@$arena = ()>) when you are done with it, if you don't want to create a
 memory leak.
 
-=item arena_ref_counts
+=head2 arena_ref_counts
+
+=for stopwords reftype
 
 Returns a hash keyed by class and reftype of all the live SVs.
 
 This is a convenient way to find out how many objects of a given class exist at
 a certain point.
 
-=item arena_table
+=head2 arena_table
 
 Formats a string table based on C<arena_ref_counts> suitable for printing.
 
+=head1 SEE ALSO
+
+=over 4
+
+L<Become a hero plumber|http://blog.woobling.org/2009/05/become-hero-plumber.html>
+L<Test::Memory::Cycle>
+L<Devel::Cycle>
+L<Devel::Refcount>
+L<Devel::Leak>
+L<Data::Structure::Util>
+
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 AUTHOR
 
-Put the correct copyright and licence information here.
+Artur Bergman <sky@apple.com>
 
-Copyright (C) 2006 by Artur Bergman
+=head1 COPYRIGHT AND LICENSE
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.6 or,
-at your option, any later version of Perl 5 you may have available.
+This software is copyright (c) 2006 by Artur Bergman.
 
-=cute
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge יובל קוג'מן (Yuval Kogman) Jesse Luehrs Brad Fitzpatrick Curtis Brandt
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Brad Fitzpatrick <brad@danga.com>
+
+=item *
+
+Curtis Brandt <curtisjbrandt@gmail.com>
+
+=back
+
+=cut
